@@ -1,6 +1,8 @@
 import os
 import json
 
+from nn_trainer.logger import Logger
+
 from nn_trainer.trainers.abstract_nn_trainer import AbstractNnTrainer
 
 from nn_trainer.metrics import *
@@ -23,7 +25,6 @@ class BasicNnTrainer(AbstractNnTrainer):
     """
     def __init__(
         self,
-        args,
         neural_network: torch.nn.Module, 
         verbose: bool = False,
         patience: int = 0,
@@ -32,13 +33,15 @@ class BasicNnTrainer(AbstractNnTrainer):
         scheduler_fn: Any = None,
         scheduler_params: Dict = field(default_factory=dict),
         dtype: Any = torch.float32,
-        logger: Any = None        
+        max_epoch_count:int = 200,
+        batch_size:int = 32,
+        output_dir:str = os.path.join(os.getcwd(), "output"),
+        logger:Logger = None,  
         ):
         """
         The base constructor
 
         Args:
-            args (Any): Command line args
             neural_network (torch.nn.Module): The network intended to be trained.  If implementation is a gan, then this refers to the 'generator' network
             optimizer_fn (Any, optional): factory method for the optimizer to be constructed and used for training during initialization. Defaults to torch.optim.Adam.
             optimizer_params (Dict, optional): parameters for the optimizer function. Defaults to dict(lr=2e-2).
@@ -47,10 +50,9 @@ class BasicNnTrainer(AbstractNnTrainer):
             dtype (Any, optional): the type of data to allocate memory with during training. Defaults to torch.float32.
             verbose (bool, optional): Will print as much output as possible if True. Defaults to False.
             patience (int, optional): describes the stopping criteria number of epochs over which training losses are relatively the same. Defaults to 0.
-            logger ([type], optional): logging utility to be used during runtime. must have an info method. Defaults to None.
+            logger (Logger, optional): logging utility to be used during runtime. must have an info method. Defaults to None.
         """
         super().__init__(
-            args,
             neural_network,
             optimizer_fn,
             optimizer_params,
@@ -59,6 +61,9 @@ class BasicNnTrainer(AbstractNnTrainer):
             dtype,
             verbose,
             patience,
+            max_epoch_count,
+            batch_size,
+            output_dir,
             logger
         )
 
@@ -94,7 +99,7 @@ class BasicNnTrainer(AbstractNnTrainer):
         
         self._eval_names = ['validation']
 
-        with open(os.path.join(self._model_directory_path, 'training_config.json'), 'w') as f: json.dump(self._args, f, indent=4)
+        #with open(os.path.join(self._model_directory_path, 'training_config.json'), 'w') as f: json.dump(self._args, f, indent=4)
 
         self._stop_training = False
 
